/**
 *******************************************************************************
 *
 * @file        MG32x02z_SPI_Init.c
 *
 * @brief       The SPI Init C file.
 *
 * @par         Project
 *              MG32x02z
 * @version     V1.03
 * @date        2023/03/06
 * @author      Megawin Software Center
 * @copyright   Copyright (c) 2022 Megawin Technology Co., Ltd.
 *              All rights reserved.
 *
 *******************************************************************************
 * @par         Disclaimer
 * The Demo software is provided "AS IS" without any warranty, either
 * expressed or implied, including, but not limited to, the implied warranties
 * of merchantability and fitness for a particular purpose. The author will
 * not be liable for any special, incidental, consequential or indirect
 * damages due to loss of data or any other reason.
 * These statements agree with the world wide and local dictated laws about
 * authorship and violence against these laws.
 *******************************************************************************
 *******************************************************************************
 */
 
/* Includes ------------------------------------------------------------------*/
#include "MG32x02z_SPI_Init.h"

/* Wizard menu ---------------------------------------------------------------*/
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
// Master Configuration
#if CONF_SPI0_MODE != 0
#if CONF_SPI0_MODE == 17    // 0x00000011
#define CONF_SPI0_CLK    CONF_SPI0_MST_PDIVIDER | CONF_SPI0_MST_PRESCALER | CONF_SPI0_MST_DIVIDER | CONF_SPI0_MST_CLOCK_SOURCE
#define CONF_SPI0_CR0    CONF_SPI0_MODE | CONF_SPI0_MST_NSSO_EN | CONF_SPI0_MST_NSS_SWEN | CONF_SPI0_MST_LSB | CONF_SPI0_MST_CPOL | CONF_SPI0_MST_CPHA | CONF_SPI0_MST_RX_CTL
#define CONF_SPI0_CR2    CONF_SPI0_MST_DATA_SIZE | CONF_SPI0_MST_DAT_LINE
#endif

// Slave Configuration
#if CONF_SPI0_MODE == 1	    // 0x00000001
#define CONF_SPI0_CLK    0x00000000 | CONF_SPI0_SLV_CLOCK_SOURCE
#define CONF_SPI0_CR0    CONF_SPI0_MODE | CONF_SPI0_SLV_NSSI_EN | CONF_SPI0_SLV_NSSI_SLE | CONF_SPI0_SLV_LSB | CONF_SPI0_SLV_CPOL | CONF_SPI0_SLV_CPHA | CONF_SPI0_SLV_ASYNC_EN | CONF_SPI0_SLV_HS_EN | CONF_SPI0_SLV_TX_CTL
#define CONF_SPI0_CR2    CONF_SPI0_SLV_DATA_SIZE | CONF_SPI0_SLV_DAT_LINE
#endif

// Master + MODF Configuration
#if CONF_SPI0_MODE == 529	  // 0x00000211
#define CONF_SPI0_CLK    CONF_SPI0_MST_MODF_PDIVIDER | CONF_SPI0_MST_MODF_PRESCALER | CONF_SPI0_MST_MODF_DIVIDER | CONF_SPI0_MST_MODF_CLOCK_SOURCE
#define CONF_SPI0_CR0    CONF_SPI0_MODE | CONF_SPI0_MST_MODF_NSSI_SLE | CONF_SPI0_MST_MODF_SEL | CONF_SPI0_MST_MODF_LSB | CONF_SPI0_MST_MODF_CPOL | CONF_SPI0_MST_MODF_CPHA | CONF_SPI0_MST_MODF_RX_CTL
#define CONF_SPI0_CR2    CONF_SPI0_MST_MODF_DATA_SIZE | CONF_SPI0_MST_MODF_DAT_LINE
#endif

// Master + NSS + MODF Configuration
#if CONF_SPI0_MODE == 785	  // 0x00000311
#define CONF_SPI0_CLK    CONF_SPI0_MST_NSS_MODF_PDIVIDER | CONF_SPI0_MST_NSS_MODF_PRESCALER | CONF_SPI0_MST_NSS_MODF_DIVIDER | CONF_SPI0_MST_NSS_MODF_CLOCK_SOURCE
#define CONF_SPI0_CR0    CONF_SPI0_MODE | CONF_SPI0_MST_NSS_MODF_SEL | CONF_SPI0_MST_NSS_MODF_NSSI_SLE | CONF_SPI0_MST_NSS_MODF_LSB | CONF_SPI0_MST_NSS_MODF_CPOL | CONF_SPI0_MST_NSS_MODF_CPHA | CONF_SPI0_MST_NSS_MODF_RX_CTL
#define CONF_SPI0_CR2    CONF_SPI0_MST_NSS_MODF_DATA_SIZE | CONF_SPI0_MST_NSS_MODF_DAT_LINE
#endif

#define CONF_SPI0_STA    SPI_TUDRF | SPI_ROVRF | SPI_WEF | SPI_MODF | SPI_TXF | SPI_RXF | SPI_RXDF | SPI_TCF | SPI_IDLF
#define CONF_SPI0_CR1    SPI_CR1_RDAT_CLR_mask_w | SPI_CR1_TDAT_CLR_mask_w
#define CONF_SPI0_INT    CONF_SPI0_INT_IEA | CONF_SPI0_INT_IDL_IE | CONF_SPI0_INT_TC_IE | CONF_SPI0_INT_RX_IE | CONF_SPI0_INT_TX_IE | CONF_SPI0_INT_MODF_IE | CONF_SPI0_INT_WE_IE | CONF_SPI0_INT_ROVR_IE | CONF_SPI0_INT_TUDR_IE
#endif

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
// (Middleware level)
// (Middleware level)
#if defined(IRQHandler_Middleware_Level_)   
    #if defined (__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050) /* ARM Compiler V6 */
        #pragma clang diagnostic push
        #pragma clang diagnostic ignored "-Wmissing-variable-declarations"
        SPI_HandleTypeDef           mSPI0;
        SPI_HandleTypeDef		    mUSPI0;
        SPI_HandleTypeDef           mUSPI1;
        #if defined(URT2_Base)
            SPI_HandleTypeDef       mUSPI2;
        #endif
        #if defined(URT3_Base)
            SPI_HandleTypeDef       mUSPI3; 
        #endif
    // ------------------------------------------------------------------------
    #else
        SPI_HandleTypeDef           mSPI0;
        SPI_HandleTypeDef		    mUSPI0;
        SPI_HandleTypeDef           mUSPI1;
        #if defined(URT2_Base)
            SPI_HandleTypeDef       mUSPI2;
        #endif
        #if defined(URT3_Base)
            SPI_HandleTypeDef       mUSPI3; 
        #endif
    #endif
#endif

/* Private function prototypes -----------------------------------------------*/
/* Exported variables --------------------------------------------------------*/
/* Exported functions --------------------------------------------------------*/
/* External vairables --------------------------------------------------------*/


/**
 *******************************************************************************
 * @brief  	    initialized SPI module.
 * @details  
 * @return	    None	
 * @note
 * @par         Example
 * @code
    SPI_Init (SPI0);
 * @endcode
 *******************************************************************************
 */
void SPI_Init (void)
{
#if CONF_SPI0_MODE != 0
    SPI0->CR0.W = CONF_SPI0_CR0 & (~SPI_CR0_EN_mask_w);
    SPI0->CR1.W = CONF_SPI0_CR1;
    SPI0->CR2.W = CONF_SPI0_CR2;
    SPI0->STA.W = CONF_SPI0_STA;
    SPI0->CLK.W = CONF_SPI0_CLK;
    SPI0->INT.W = CONF_SPI0_INT;
    SPI0->CR0.W = CONF_SPI0_CR0;
#endif
}

